package jalview.analysis.scoremodels;

/**
 * An interface that describes classes that can compute similarity (aka
 * substitution) scores for pairs of residues
 */
public interface PairwiseScoreModelI
{
  /**
   * Answers a similarity score between two sequence characters (for
   * substitution of the first by the second). Typically the highest scores are
   * for identity, and the lowest for substitution of a residue by one with very
   * different properties.
   * 
   * @param c
   * @param d
   * @return
   */
  abstract public float getPairwiseScore(char c, char d);

  /**
   * Returns a readable name for the model, suitable for display in menus
   * 
   * @return
   */
  String getName();

  /**
   * Answers true if the model is applicable to nucleotide data
   * 
   * @return
   */
  boolean isDNA();

  /**
   * Answers true if the model is applicable to peptide data
   * 
   * @return
   */
  boolean isProtein();

}
